'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var rxjs = require('rxjs');
var operators = require('rxjs/operators');
var vueDemi = require('vue-demi');
var shared = require('@vueuse/shared');

function from(value) {
    if (vueDemi.isRef(value)) {
        return new rxjs.Observable((subscriber) => {
            vueDemi.watch(value, val => subscriber.next(val));
        });
    }
    else {
        return rxjs.from(value);
    }
}
function fromEvent(value, event) {
    return from(value).pipe(operators.filter(value => value instanceof HTMLElement), operators.mergeMap(value => rxjs.fromEvent(value, event)));
}

function toObserver(value) {
    return {
        next: (val) => {
            value.value = val;
        },
    };
}

function useObservable(observable) {
    const value = vueDemi.ref();
    const subscription = observable.subscribe(val => (value.value = val));
    shared.tryOnUnmounted(() => {
        subscription.unsubscribe();
    });
    return value;
}

function useSubscription(subscription) {
    shared.tryOnUnmounted(() => {
        subscription.unsubscribe();
    });
}

exports.from = from;
exports.fromEvent = fromEvent;
exports.toObserver = toObserver;
exports.useObservable = useObservable;
exports.useSubscription = useSubscription;
